==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/DataGridFilterDialogDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogOpeningEventArgsDescriptionMetadata } from "./GridFilterDialogOpeningEventArgsDescriptionMetadata";
import { GridFilterDialogFilterChangeEventArgsDescriptionMetadata } from "./GridFilterDialogFilterChangeEventArgsDescriptionMetadata";
import { FilterDialogRenderCompletedEventArgsDescriptionMetadata } from "./FilterDialogRenderCompletedEventArgsDescriptionMetadata";
import { DataGridFilterDialogDescription } from "./DataGridFilterDialogDescription";
/**
 * @hidden
 */
export let DataGridFilterDialogDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataGridFilterDialogDescriptionMetadata extends Base {
        static b(a) {
            if (DataGridFilterDialogDescriptionMetadata.a == null) {
                DataGridFilterDialogDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataGridFilterDialogDescriptionMetadata.c(DataGridFilterDialogDescriptionMetadata.a);
            }
            if (a.j(DataGridFilterDialogDescriptionMetadata.a)) {
                return;
            }
            a.y(DataGridFilterDialogDescriptionMetadata.a);
            GridFilterDialogOpeningEventArgsDescriptionMetadata.d(a);
            GridFilterDialogFilterChangeEventArgsDescriptionMetadata.d(a);
            FilterDialogRenderCompletedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("IsAnimationEnabled", "Boolean");
            a.item("PixelScalingRatio", "Number:double");
            a.item("ActualPixelScalingRatio", "Number:double");
            a.item("IconColor", "Brush");
            a.item("ViewSize", "Number:double");
            a.item("DialogOpeningRef", "EventRef::dialogOpening");
            a.item("FilterChangingRef", "EventRef::filterChanging");
            a.item("FilterChangedRef", "EventRef::filterChanged");
            a.item("RenderCompletedRef", "EventRef::renderCompleted");
        }
        static d(a) {
            DataGridFilterDialogDescriptionMetadata.b(a);
            a.aa("DataGridFilterDialog", () => new DataGridFilterDialogDescription());
            a.z("DataGridFilterDialog", DataGridFilterDialogDescriptionMetadata.a);
        }
    }
    DataGridFilterDialogDescriptionMetadata.$t = /*@__PURE__*/ markType(DataGridFilterDialogDescriptionMetadata, 'DataGridFilterDialogDescriptionMetadata');
    DataGridFilterDialogDescriptionMetadata.a = null;
    return DataGridFilterDialogDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DataGridFilterDialogDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogOpeningEventArgsDescriptionMetadata } from "./GridFilterDialogOpeningEventArgsDescriptionMetadata";
import { GridFilterDialogFilterChangeEventArgsDescriptionMetadata } from "./GridFilterDialogFilterChangeEventArgsDescriptionMetadata";
import { FilterDialogRenderCompletedEventArgsDescriptionMetadata } from "./FilterDialogRenderCompletedEventArgsDescriptionMetadata";
import { DataGridFilterDialogDescription } from "./DataGridFilterDialogDescription";
/**
 * @hidden
 */
export let DataGridFilterDialogDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataGridFilterDialogDescriptionMetadata extends Base {
        static b(a) {
            if (DataGridFilterDialogDescriptionMetadata.a == null) {
                DataGridFilterDialogDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataGridFilterDialogDescriptionMetadata.c(DataGridFilterDialogDescriptionMetadata.a);
            }
            if (a.k(DataGridFilterDialogDescriptionMetadata.a)) {
                return;
            }
            a.aa(DataGridFilterDialogDescriptionMetadata.a);
            GridFilterDialogOpeningEventArgsDescriptionMetadata.d(a);
            GridFilterDialogFilterChangeEventArgsDescriptionMetadata.d(a);
            FilterDialogRenderCompletedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("IsAnimationEnabled", "Boolean");
            a.item("PixelScalingRatio", "Number:double");
            a.item("ActualPixelScalingRatio", "Number:double");
            a.item("IconColor", "Brush");
            a.item("ViewSize", "Number:double");
            a.item("DialogOpeningRef", "EventRef::dialogOpening");
            a.item("FilterChangingRef", "EventRef::filterChanging");
            a.item("FilterChangedRef", "EventRef::filterChanged");
            a.item("RenderCompletedRef", "EventRef::renderCompleted");
        }
        static d(a) {
            DataGridFilterDialogDescriptionMetadata.b(a);
            a.ac("DataGridFilterDialog", () => new DataGridFilterDialogDescription());
            a.ab("DataGridFilterDialog", DataGridFilterDialogDescriptionMetadata.a);
        }
    }
    DataGridFilterDialogDescriptionMetadata.$t = /*@__PURE__*/ markType(DataGridFilterDialogDescriptionMetadata, 'DataGridFilterDialogDescriptionMetadata');
    DataGridFilterDialogDescriptionMetadata.a = null;
    return DataGridFilterDialogDescriptionMetadata;
})();
